@@ -1,9 +1,7 @@
 from typing import List
 
-from abc import ABC
 
-
-class Config(ABC):
+class Config:
     USER_AGENT: str = "Python Valorant API Wrapper"
     BASE_URL: str = "https://api.henrikdev.xyz"
     ALL_REGIONS: List[str] = ["eu", "na", "ap", "kr", "latam", "br"]
